library(dplyr)
load('movies_shows.RData')

distinct(movies, country)

sum(is.na(movies$country))

summarise(movies,
          n.na = sum(is.na(country)))

summarise(movies,
          n.cat = n_distinct(country))

tab = table(movies$country)
tab

dtab = count(movies, country)
dtab
arrange(dtab, desc(n))

dtab.nona = na.omit(dtab)
arrange(dtab.nona, desc(n))

prop.table(0:4)

prop.table(tab)


dtab.nona = mutate(dtab.nona,
                   p = prop.table(n))
arrange(dtab.nona, desc(p))


dtab_20 = slice_max(dtab.nona, n, n = 20)

x = pull(dtab_20, n, name = country)

barplot(x, las = 2, cex.names = 0.7)


pie(x)

pie(pull(dtab, n, country))


## Reduïm les observacions amb menys de 50 casos a una sola fila, mantenint 
## els noms de les columnes original.
dtab_other = summarise(filter(dtab.nona, n < 50),
                       country = 'Other countries',
                       n = sum(n),
                       p = sum(p))
dtab_l50 = bind_rows(
  filter(dtab.nona, n >= 50),
  dtab_other)

pie(pull(dtab_l50, n, country))


summary(movies$added_year)

mean(movies$added_year)

mean(movies$added_year, na.rm=TRUE)

summarise(movies,
          `Min.` = min(added_year, na.rm=TRUE),
          `1st Qu.` = quantile(added_year, probs = 0.25, na.rm=TRUE),
          `Median` = median(added_year, na.rm=TRUE),
          `Mean` = mean(added_year, na.rm=TRUE),
          `3st Qu.` = quantile(added_year, probs = 0.75, na.rm=TRUE),
          `Max.` = max(added_year, na.rm=TRUE),
          `NA's` = sum(is.na(added_year)))

summarise(movies,
          `Obs.` = n(),
          `sd` = sd(added_year, na.rm=TRUE),
          `RIQ` = IQR(added_year, na.rm=TRUE))


summarise_generic = function(.data, x){
  summarise(.data,
            `Obs.` = n(),
            `Mean` = mean({{ x }}, na.rm=TRUE),
            `sd` = sd({{ x }}, na.rm=TRUE),
            `Min.` = min({{ x }}, na.rm=TRUE),
            `1st Qu.` = quantile({{ x }}, probs = 0.25, na.rm=TRUE),
            `Median` = median({{ x }}, na.rm=TRUE),
            `3st Qu.` = quantile({{ x }}, probs = 0.75, na.rm=TRUE),
            `Max.` = max({{ x }}, na.rm=TRUE),
            `RIQ` = IQR({{ x }}, na.rm=TRUE),
            `NA's` = sum(is.na({{ x }}))
  )
}
summarise_generic(movies, x = added_year)


hist(movies$added_year, main = "Histograma", 
     xlab = 'Any d\'incorporació a Netflix', ylab = 'Freqüència')

boxplot(movies$added_year, main = "Gràfic de caixa", 
        xlab = 'Any d\'incorporació a Netflix', horizontal = TRUE)

barplot(table(movies$added_year), 
        xlab = 'Any d\'incorporació a Netflix', main = "Gràfic de barres")

tab = with(movies,
           table(united_states, movie_duration_cat))
tab

tab_na = with(movies,
              table(united_states, movie_duration_cat, useNA='ifany'))
tab_na

addmargins(tab)

prop.table(tab)

prop.table(tab, margin = 1)

prop.table(tab, margin = 2)

barplot(tab, legend = c('Fora EEUU', 'Dins EEUU'))
barplot(tab, legend = c('Fora EEUU', 'Dins EEUU'), beside = TRUE)
barplot(t(tab), legend = c('Llarga', 'Mitjana', 'Curta'), beside = TRUE, 
        args.legend = list(x="top"))

barplot(prop.table(tab, 2), legend = c('Fora EEUU', 'Dins EEUU'), 
        args.legend = list(x="top"), ylim = c(0,1.5), axes = FALSE)

with(movies, cor(release_year, movie_duration))


with(movies, 
     plot(release_year, movie_duration, 
          xlab = 'Any de llançament', ylab = 'Durada de la pel·lícula (minuts)'))

with(filter(movies, release_year < 1970),
     cor(release_year, movie_duration))

with(filter(movies, release_year >= 1970),
     cor(release_year, movie_duration))


with(movies, tapply(movie_duration, united_states, mean))

movies_grouped = group_by(movies, united_states)
summarise_generic(movies_grouped, x = movie_duration)

boxplot(movie_duration~united_states, movies,
        xlab = 'Pel·lícules d\'Estats Units', ylab = 'Duració (minuts)')